@@ -3,8 +3,10 @@
 
 from .common import AbstractFactory
 from .deprecated_stuff import dict_factory, parse, ParserFactory, SerializerFactory
+from .exceptions import InvalidFieldError
 from .factory import Factory
 from .naming import NameStyle
+from .parsers import PARSER_EXCEPTIONS
 from .schema import Schema
 
 __all__ = [
@@ -16,4 +18,6 @@ __all__ = [
     "Schema",
     "Factory",
     "AbstractFactory",
+    "PARSER_EXCEPTIONS",
+    "InvalidFieldError",
 ]
